@@ -28,6 +28,16 @@ const G4double TG4G3Units::fgkMassDensity = g / cm3;
 const G4double TG4G3Units::fgkAtomicWeight = g / mole;
 const G4double TG4G3Units::fgkField = kilogauss;
 
+const G4double TG4G3Units::fgkInverseLength = 1. / cm;
+const G4double TG4G3Units::fgkInverseAngle = 1. / deg;
+const G4double TG4G3Units::fgkInverseTime = 1. / s;
+const G4double TG4G3Units::fgkInverseCharge = 1. / eplus;
+const G4double TG4G3Units::fgkInverseEnergy = 1. / GeV;
+const G4double TG4G3Units::fgkInverseMass = 1. / GeV;
+const G4double TG4G3Units::fgkInverseMassDensity = 1. / g * cm3;
+const G4double TG4G3Units::fgkInverseAtomicWeight = 1. / g * mole;
+const G4double TG4G3Units::fgkInverseField = 1. / kilogauss;
+
 //_____________________________________________________________________________
 TG4G3Units::~TG4G3Units()
 {
