@@ -19,6 +19,7 @@
 #include "TG4GeometryServices.h"
 #include "TG4Globals.h"
 #include "TG4Limits.h"
+#include "TG4Medium.h"
 #include "TG4PhysicsManager.h"
 #include "TG4RegionsMessenger.h"
 
@@ -39,87 +40,15 @@
 #include <set>
 #include <fstream>
 
-TG4RegionsManager* TG4RegionsManager::fgInstance = 0;
-
-const G4int TG4RegionsManager::fgkDefaultRangePrecision = 5;
-const G4double TG4RegionsManager::fgkDefaultEnergyTolerance = 0.01;
-const G4int TG4RegionsManager::fgkNofBins = 10;
-const G4int TG4RegionsManager::fgkMinRangeOrder = -3;
-const G4int TG4RegionsManager::fgkMaxRangeOrder = 6;
-const G4String TG4RegionsManager::fgkDefaultRegionName =
-  "RegionWithDefaultCuts";
-const G4String TG4RegionsManager::fgkDefaultFileName = "regions.dat";
-
 //_____________________________________________________________________________
 TG4RegionsManager::TG4RegionsManager()
-  : TG4Verbose("regionsManager"),
-    fMessenger(this),
-    fRangePrecision(fgkDefaultRangePrecision),
-    fEnergyTolerance(fgkDefaultEnergyTolerance),
-    fApplyForGamma(true),
-    fApplyForElectron(true),
-    fApplyForPositron(true),
-    fApplyForProton(true),
-    fFileName(),
-    fIsCheck(false),
-    fIsPrint(false),
-    fIsG4Table(false),
-    fIsSave(false),
-    fIsLoad(false)
-{
-  /// Default constructor
-
-  fgInstance = this;
-}
-
-//_____________________________________________________________________________
-TG4RegionsManager::~TG4RegionsManager()
-{
-  /// Destructor
-
-  fgInstance = 0;
-}
+ : fMessenger(this)
+{}
 
 //
 // private methods
 //
 
-//_____________________________________________________________________________
-G4double TG4RegionsManager::GetGlobalEnergyCut(TG4G3Cut cutType) const
-{
-  /// Return global cut in energy of given cutType.
-  /// Return DBL_MAX if cut value is not defined
-
-  TG4boolVector* isCutVector =
-    TG4G3PhysicsManager::Instance()->GetIsCutVector();
-  TG4G3CutVector* cutVector = TG4G3PhysicsManager::Instance()->GetCutVector();
-
-  G4double cutValue = DBL_MAX;
-  if ((*isCutVector)[cutType] && (*cutVector)[cutType] > DBL_MIN) {
-    cutValue = (*cutVector)[cutType];
-  }
-
-  return cutValue;
-}
-
-//_____________________________________________________________________________
-G4double TG4RegionsManager::GetEnergyCut(
-  TG4Limits* limits, TG4G3Cut cutType, G4double globalCutValue) const
-{
-  /// Return cut in energy defined in limits of given cutType.
-  /// Return DBL_MAX if cut value is not defined.
-
-  G4double cut = DBL_MAX;
-  if (limits->GetCutVector() && (*limits->GetCutVector())[cutType] > DBL_MIN) {
-    cut = (*limits->GetCutVector())[cutType];
-  }
-  else {
-    cut = globalCutValue;
-  }
-
-  return cut;
-}
-
 //_____________________________________________________________________________
 G4bool TG4RegionsManager::Iterate(G4double energyCut, G4double& lowerCut,
   G4double& higherCut, G4double defaultRangeCut, G4double lowEdgeEnergy,
@@ -339,26 +268,6 @@ TG4RegionsManager::GetRangeCut(G4double energyCut,
   return {calcEnergyCut, rangeCut};
 }
 
-//_____________________________________________________________________________
-G4bool TG4RegionsManager::IsCoupleUsedInTheRegion(
-  const G4MaterialCutsCouple* couple, const G4Region* region) const
-{
-  /// Reimplemented G4ProductionCutsTable::IsCoupleUsedInTheRegion
-  /// which is declared private
-
-  G4ProductionCuts* productionCuts = region->GetProductionCuts();
-  std::vector<G4Material*>::const_iterator itm = region->GetMaterialIterator();
-  size_t nofMaterials = region->GetNumberOfMaterials();
-  for (size_t i = 0; i < nofMaterials; i++, itm++) {
-    if (couple->GetMaterial() == (*itm) &&
-        couple->GetProductionCuts() == productionCuts) {
-      return true;
-    }
-  }
-
-  return false;
-}
-
 //_____________________________________________________________________________
 void TG4RegionsManager::CheckRegionsRanges() const
 {
@@ -401,90 +310,6 @@ void TG4RegionsManager::CheckRegionsRanges() const
   }
 }
 
-//_____________________________________________________________________________
-void TG4RegionsManager::CheckRegionsInGeometry() const
-{
-  /// Loop over all logical volumes and check if the region to which
-  /// the volume belongs correspond to its material
-
-  if (VerboseLevel() > 0) {
-    G4cout << ".. Checking regions materials " << G4endl;
-  }
-
-  Bool_t good = true;
-  G4LogicalVolumeStore* lvStore = G4LogicalVolumeStore::GetInstance();
-  for (G4int i = 0; i < G4int(lvStore->size()); i++) {
-
-    G4LogicalVolume* lv = (*lvStore)[i];
-
-    // skip world volume
-    if (lv == TG4GeometryServices::Instance()->GetWorld()->GetLogicalVolume())
-      continue;
-
-    // skip volume without medium
-    TG4Medium* medium =
-      TG4GeometryServices::Instance()->GetMediumMap()->GetMedium(lv, false);
-    if (!medium) continue;
-
-    if (lv->GetRegion()->GetName() != lv->GetMaterial()->GetName() &&
-        lv->GetRegion()->GetName() != fgkDefaultRegionName) {
-
-      G4cout << "The region name " << lv->GetRegion()->GetName()
-             << " for LV = " << lv->GetName()
-             << " does not match its material name "
-             << lv->GetMaterial()->GetName() << G4endl;
-
-      good = false;
-    }
-  }
-  if (good) {
-    G4cout << ".. Regions are consistent with materials." << G4endl;
-  }
-  else {
-    G4cout << ".. Found inconsistencies between regions and materials."
-           << G4endl;
-  }
-}
-
-//_____________________________________________________________________________
-void TG4RegionsManager::PrintLegend(std::ostream& output) const
-{
-  /// Print the range data legend
-
-  //clang-format off
-  output << std::setw(30) << std::left << "# material name"
-         << "  rangeGam[mm]"
-         << "  rangeEle[mm]"
-         << "   cutGam[GeV]"
-         << "   cutEle[GeV]"
-         << " vmcCutGam[GeV]"
-         << " vmcCutEle[GeV]" << G4endl;
-  //clang-format on
-}
-
-//_____________________________________________________________________________
-void TG4RegionsManager::PrintRegionData(std::ostream& output,
-  const G4String& matName, const TG4RegionData& values) const
-{
-  /// Print one region data.
-  /// The regions names are printed within '' and separated from the following date
-  /// with ';' to facilitate reading data back. The procedure then works only with
-  /// material names that do not contain these two special characters.
-
-  auto name = "\'" + matName + "\';";
-
-  // Print all data
-  //clang-format off
-  output << std::setw(30) << std::left << name << "  "
-         << std::scientific << values[fgkRangeGamIdx] << "  "
-         << std::scientific << values[fgkRangeEleIdx] << "  "
-         << std::scientific << values[fgkCutGamIdx] / TG4G3Units::Energy() << "  "
-         << std::scientific << values[fgkCutEleIdx] / TG4G3Units::Energy() << "  "
-         << std::scientific << values[fgkVmcCutGamIdx] / TG4G3Units::Energy() << "  "
-         << std::scientific << values[fgkVmcCutEleIdx] / TG4G3Units::Energy() << G4endl;
-  //clang-format on
-}
-
 //_____________________________________________________________________________
 void TG4RegionsManager::PrintFromMap(std::ostream& output) const
 {
@@ -502,68 +327,6 @@ void TG4RegionsManager::PrintFromMap(std::ostream& output) const
   }
 }
 
-//_____________________________________________________________________________
-void TG4RegionsManager::PrintFromG4Table(std::ostream& output) const
-{
-  /// Loop over the production cuts table and print the production ranges
-  /// and cuts from the table and the VMC cuts from the TG4Limits
-  /// associated with the production cuts material.
-
-  G4ProductionCutsTable* productionCutsTable =
-    G4ProductionCutsTable::GetProductionCutsTable();
-
-  if (productionCutsTable->GetTableSize() == 0) {
-    G4cout << "No production cuts defined." << G4endl;
-    return;
-  }
-
-  PrintLegend(output);
-
-  for (G4int i = 0; i < G4int(productionCutsTable->GetTableSize()); i++) {
-    const G4MaterialCutsCouple* couple =
-      productionCutsTable->GetMaterialCutsCouple(i);
-
-    const G4Material* material = couple->GetMaterial();
-    G4ProductionCuts* cuts = couple->GetProductionCuts();
-
-    G4double rangeGam = cuts->GetProductionCut(0);
-    G4double rangeEle = cuts->GetProductionCut(1);
-    // if ( couple->IsRecalcNeeded() ) {
-    //  TG4Globals::Warning("TG4RegionsManager", "PrintProductionCuts",
-    //     "Recalculation is needed - the energy cuts may be wrong");
-    // }
-
-    const std::vector<G4double>* energyCutsGam =
-      productionCutsTable->GetEnergyCutsVector(0);
-    const std::vector<G4double>* energyCutsEle =
-      productionCutsTable->GetEnergyCutsVector(1);
-
-    G4double cutGam = (*energyCutsGam)[couple->GetIndex()];
-    G4double cutEle = (*energyCutsEle)[couple->GetIndex()];
-
-    // Get limits via material
-    TG4Limits* limits =
-      TG4GeometryServices::Instance()->FindLimits(material, true);
-
-    G4double cutGamLimits = DBL_MAX;
-    G4double cutEleLimits = DBL_MAX;
-    if (!limits) {
-      TG4Globals::Warning("TG4RegionsManager", "CheckRegions",
-        "Limits for material " + TString(material->GetName()) + " not found. " +
-          TG4Globals::Endl());
-    }
-    else {
-      cutGamLimits = GetEnergyCut(limits, kCUTGAM, DBL_MAX);
-      cutEleLimits = GetEnergyCut(limits, kCUTELE, DBL_MAX);
-    }
-
-    G4String matName = material->GetName();
-    TG4RegionData values =
-      {rangeGam, rangeEle, cutGam, cutEle, cutGamLimits, cutEleLimits};
-
-    PrintRegionData(output, matName, values);
-  }
-}
 
 //
 // public methods
@@ -824,30 +587,6 @@ void TG4RegionsManager::CheckRegions() const
   CheckRegionsInGeometry();
 }
 
-//_____________________________________________________________________________
-void TG4RegionsManager::SaveRegions()
-{
-  /// Dump all regions data in a file
-
-  // Open file
-  auto fileName = fFileName.empty() ? fgkDefaultFileName : fFileName;
-  std::ofstream fileOutput;
-  fileOutput.open(fileName, std::ios::out);
-  if (! fileOutput.is_open()) {
-    TG4Globals::Warning("TG4RegionsManager", "SaveRegions",
-      "Saving regions in file " + TString(fileName.data()) + " has failed.");
-    return;
-  }
-
-  if (VerboseLevel() > 0) {
-    auto which = (fIsG4Table) ?  " from production cuts table" : "";
-    G4cout << "Saving regions" << which << " in file: " << fileName << G4endl;
-  }
-
-  PrintRegions(fileOutput);
-  fileOutput.close();
-}
-
 //_____________________________________________________________________________
 void TG4RegionsManager::LoadRegions()
 {
@@ -1014,77 +753,6 @@ void TG4RegionsManager::DumpRegion(const G4String& volName) const
   }
 }
 
-//_____________________________________________________________________________
-void TG4RegionsManager::DumpRegionStore() const
-{
-  /// Dump all region properties:
-  /// production cuts, volumes list and material list
-
-  auto regionStore = G4RegionStore::GetInstance();
-
-  G4cout << "========= Region Store Dump ======================================"
-         << G4endl;
-
-  for (auto region : *regionStore ) {
-    G4cout << region->GetName() << ":" << G4endl;
-
-    auto cuts = region->GetProductionCuts();
-    if (cuts != nullptr) {
-      auto rangeGam = cuts->GetProductionCut(0);
-      auto rangeEle = cuts->GetProductionCut(1);
-      G4cout << "  ProductionCuts: rangeGam=" << rangeGam << "  rangeEle=" << rangeEle << G4endl;
-    }
-
-    size_t lvCounter = 0;
-    auto lvIt = region->GetRootLogicalVolumeIterator();
-    G4cout << "  RootVolumes: ";
-    while (lvCounter < region->GetNumberOfRootVolumes()) {
-      G4cout << " " << (*lvIt++)->GetName() << "; ";
-      ++lvCounter;
-    }
-    G4cout << G4endl;;
-
-    size_t matCounter = 0;
-    auto matIt = region->GetMaterialIterator();
-    G4cout << "  Materials: ";
-    while (matCounter < region->GetNumberOfMaterials()) {
-      G4cout << " " << (*matIt++)->GetName() << "; ";
-      ++matCounter;
-    }
-    G4cout << G4endl;;
-  }
-
-  G4cout << "========= End Region Store Dump =================================="
-         << G4endl;
-}
-
-//_____________________________________________________________________________
-void TG4RegionsManager::SetPrint(G4bool isPrint, G4bool isG4Table)
-{
-/// Set the option to print all regions either from local map
-/// or the production cuts table
-
-  fIsPrint = isPrint;
-  fIsG4Table = isG4Table;
-}
-
-//_____________________________________________________________________________
-void TG4RegionsManager::SetSave(G4bool isSave, G4bool isG4Table)
-{
-/// Set the option to save all regions in a file.
-//  The options fIsSave and fIsLoad cannot be activated both
-//  in the same run.
-
-  if (fIsLoad) {
-    TG4Globals::Warning("TG4RegionsManager", "SetSave",
-      "\"Load\" option is active. The input file " + fFileName +
-      " will be overwritten.");
-  }
-
-  fIsSave = isSave;
-  fIsG4Table = isG4Table;
-}
-
 //_____________________________________________________________________________
 void TG4RegionsManager::SetLoad(G4bool isLoad)
 {
